!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_dij0
!! NAME
!! calc_dij0
!! 
!! FUNCTION
!! Compute initial values of Dij = Dij0 (contribution of vh(tnZc))
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS
!!  pawarray
!!    %kij(lmn2_size)= Kinetic overlap operator
!!    %q00hat(mesh_size)= Qij_hat terms with i,j=(0,0)
!!    %qijl(lmn2_size,l_size**2)= qij_l terms
!!    %vhnzcij(lmn2_size)= (i,j) channel of the Hartree term inside
!!                         the spheres for the density nZc
!!    %vhtnzcij(lmn2_size)= matrix element of the Hartree potential of
!!                          the ps-density of the nucleus+core electrons
!!  pawdata
!!    %indlmn(6,lmn_size)= Gives l,m,n,ln,lm,s for i=lmn
!!  pawps
!!    %vhtnzc(bigmesh_size)= Hartree potential of the ps-density
!!                           of the nucleus + core electrons
!!  pshead
!!    %lmn_size= Number of elements for the paw basis
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %rad_step= Step corresponding to radial mesh
!!   
!! OUTPUT
!!  pawps
!!    %dij0(lmn2_size)= Part of the Dij term calculated in the psp part
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!      ctrap
!!
!! SOURCE

 subroutine calc_dij0(pawarray,pawdata,pawps,pshead)

 use defs_basis
 use defs_pawps
 
 implicit none
 
!Arguments ---------------------------------------------
!These types are defined in defs_pawps
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: ilm,ilmn,j0lmn,jlm,jlmn,klmn,iovl,ir
 real(dp) :: intvh
 real(dp),allocatable :: ff(:)
 
! *************************************************************************

 pawps%dij0=zero

!Computation of int[vh(tnzc)*Qijhat(r)dr]
!----------------------------------------
 allocate (ff(pshead%mesh_size))
 do ir=1,pshead%mesh_size
  ff(ir)=pawps%vhtnzc(ir)*pawarray%q00hat(ir)
 enddo
 call ctrap(pshead%mesh_size,ff,pshead%rad_step,intvh)

 do jlmn=1,pshead%lmn_size
  j0lmn=jlmn*(jlmn-1)/2;jlm=pawdata%indlmn(4,jlmn)
  do ilmn=1,jlmn
   klmn=j0lmn+ilmn;ilm=pawdata%indlmn(4,ilmn)
   if (jlm==ilm) pawps%dij0(klmn)=-intvh*pawarray%qijl(klmn,1)*sqrt(four_pi)
  enddo
 enddo

!Computation of dij0
!-------------------
 pawps%dij0(:)=pawps%dij0(:)+pawarray%kij(:)&
&             +pawarray%vhnzcij(:)-pawarray%vhtnzcij(:)

 end subroutine
!!***
