!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_psden
!! NAME 
!! calc_psden
!!
!! FUNCTION
!! Calculate a pseudo-density from an original density
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (GJ, FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  mesh= dimension of nc
!!  nc= density to be pseudized
!!  rc= cut-off radius
!!  step= step of the linear radial grid
!!
!! OUTPUT
!!  ff= pseudized density
!!
!! NOTES
!! ff=bb*sin(aa*r)/r
!!
!! PARENTS
!!      calc_tcore
!!
!! CHILDREN
!!
!! SOURCE

 subroutine calc_psden(ff,mesh,nc,rc,step)

 use defs_basis

 implicit none

!Arguments ------------------------------------
 integer :: mesh
 real(dp) :: step
 real(dp) :: nc(mesh),ff(mesh)

!Local variables-------------------------------
 integer :: ii,nc1
 real (dp) :: aa,aa1,aa2,bb,c2,eps,f0,f0p,ff1,ff2,ffa,rj,rc,rc1

! *************************************************************************

 if (abs(maxval(nc))<tol10) then
  ff=zero

 else

  eps=1.0d-3
  rc1=rc/1.2d0
  nc1=int(rc1/step)+1
  rc1=(nc1-1)*step

  f0=nc(nc1)
  f0p=(nc(nc1+1)-nc(nc1-1))/(2.d0*step)

  c2=f0/(f0+rc1*f0p)
  if (c2<0.d0) then
   aa1=pi/2.d0+eps
   aa2=pi-eps
  else
   if (c2<1.d0) then
    aa1=pi+eps
    aa2=3.d0*pi/2.d0-eps
   else
    aa1=eps
    aa2=pi/2.d0-eps
   endif
  endif
  ff1=tan(aa1)-c2*aa1
  ff2=tan(aa2)-c2*(aa2)

  if (ff1*ff2>0.d0) then
   print *, "Big pb in calc_psdens"
   stop
  endif

  do while (abs(ff2-ff1)>tol10) 
   aa=(aa1+aa2)/2.d0
   ffa=tan(aa)-c2*(aa)
   if (ffa*ff1>0.d0) then
    ff1=ffa
    aa1=aa
   else
    ff2=ffa
    aa2=aa
   endif
  enddo

  bb=rc1*f0/sin(aa)
  aa=aa/rc1
  rj=step
  ff(1)=aa*bb
  do ii=2,nc1
   ff(ii) = bb*sin(aa*rj)/rj
   rj=rj+step
  enddo
  do ii=nc1+1,mesh
   ff(ii) = nc(ii)
  enddo

 endif

end subroutine
!!***

