!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_qijl
!! NAME
!! calc_qijl
!! 
!! FUNCTION
!! Compute Q_ijl terms
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS 
!!  pawps
!!    %phi(mesh_size,basis_size)= PAW atomic wavefunctions
!!                                on the radial grid
!!    %tphi(mesh_size,basis_size)= PAW atomic pseudo-wavefunctions
!!                                 on the radial grid
!!  pawdata
!!    %rad(bigmesh_size)= Coordinates of the radial grid
!!  pshead
!!    %lmn_size= Number of elements for the paw basis
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %rad_step= Step corresponding to radial mesh
!! 
!! OUTPUT
!!  pawarray
!!    %qijl(lmn2_size,l_size**2)= qij_l terms
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!      ctrap,realgaunt
!!
!! SOURCE

 subroutine calc_qijl(pawarray,pawdata,pawps,pshead)

 use defs_basis
 use defs_pawps

 implicit none
 
!Arguments ---------------------------------------------
!These types are defined in defs_pawps
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: il,ilmn,ilmin,ilmax,iln,im,j0lmn,jl,jlmn,jln,jm
 integer :: klmn,ll,lm0,mm
 real(dp) :: intg,realgaunt
 real(dp),allocatable :: ff(:)

!--------------------------------------------------------

 pawarray%qijl=zero
 
 allocate(ff(pshead%mesh_size))

 do jlmn=1,pshead%lmn_size
  jl =pawdata%indlmn(1,jlmn)
  jm =pawdata%indlmn(2,jlmn)
  jln=pawdata%indlmn(5,jlmn)
  j0lmn=jlmn*(jlmn-1)/2
  do ilmn=1,jlmn
   il= pawdata%indlmn(1,ilmn)
   im= pawdata%indlmn(2,ilmn)
   iln=pawdata%indlmn(5,ilmn)
   klmn=j0lmn+ilmn;ilmin=abs(jl-il);ilmax=jl+il
   do ll=ilmin,ilmax,2
    lm0=ll*ll+ll+1;ff(1)=zero
    ff(2:pshead%mesh_size)=&
&    ( pawps%phi (2:pshead%mesh_size,iln)&
&     *pawps%phi (2:pshead%mesh_size,jln)&
&    - pawps%tphi(2:pshead%mesh_size,iln)&
&     *pawps%tphi(2:pshead%mesh_size,jln) )&
&    *pawdata%rad(2:pshead%mesh_size)**ll
    call ctrap(pshead%mesh_size,ff,pshead%rad_step,intg)
    do mm=-ll,ll
     pawarray%qijl(klmn,lm0+mm)=intg*realgaunt(il,im,jl,jm,ll,mm,il+jl+1)
    enddo
   enddo
  enddo
 enddo

 deallocate(ff)

 end subroutine
!!***
