!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_rhoij0
!! NAME
!! calc_rhoij0
!! 
!! FUNCTION
!! Compute initial values (atomic initialization) of rhoij0
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawarray
!!    %valeden4pr2(bigmesh_size) = Density 4*pi*r^2*n1,
!!                                 coming from the code Atompaw
!!  pawps
!!    %phi(mesh_size,basis_size)= PAW atomic wavefunctions
!!                                on the radial grid
!!  pshead
!!    %basis_size= Number of elements for the paw nl basis
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!
!! OUTPUT
!!  pawps
!!    %rhoij0= Atomic initialization of rhoij
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!
!! SOURCE

 subroutine calc_rhoij0(pawarray,pawdata,pawps,pshead)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
!These types are defined in defs_pawps
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: ib,ilmn,ilmn0,info,ir,ll2,nn,pp
 real(dp), allocatable :: aa(:,:),occ(:)
 integer, allocatable :: iwork(:)

! *************************************************************************

 pawps%rhoij0=zero

!Deduce occupations from val. density and wave functions
 nn=pshead%basis_size;allocate(aa(nn,nn),occ(nn),iwork(nn))
 pp=10;do while (pshead%mesh_size<pp*nn);pp=pp-1;enddo
 if (pp==0) stop "Bug in calc_rhoij0 !"
 do ir=1,nn
  occ(ir)=pawarray%valeden4pr2(pshead%mesh_size+1-pp*ir)
  do ib =1,nn
   aa(ir,ib)=pawps%phi(pshead%mesh_size+1-pp*ir,ib)**2
  enddo
 enddo
 call DGETRF(nn,nn,aa,nn,iwork,info)
 call DGETRS('N',nn,1,aa,nn,iwork,occ,nn,info)
 deallocate(aa,iwork)

!Filter occ
 do ib=1,pshead%basis_size
  if (abs(occ(ib)-nint(occ(ib)))<tol8) occ(ib)=nint(occ(ib))
 enddo

!Store Rhoij0
 ilmn0=0
 do ib=1,pshead%basis_size
  ll2=2*pshead%orbitals(ib)+1
  do ilmn=ilmn0+1,ilmn0+ll2
   pawps%rhoij0(ilmn*(ilmn+1)/2)=occ(ib)/dble(ll2)
  enddo
  ilmn0=ilmn0+ll2
 enddo

 deallocate(occ)

 end subroutine
!!***

