!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_vhnzc
!! NAME
!! calc_vhnzc
!! 
!! FUNCTION
!! Compute vh(nZc) and the <phi_i|vh(nZc)|phi_j> matrix elements
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS 
!!  pawarray
!!    %coreden4pr2(bigmesh_size)= Core density multiplied by 4Pi.r2
!!  pawdata
!!    %indlmn(6,lmn_size)= Gives l,m,n,ln,lm,s for i=lmn
!!    %rad(bigmesh_size)= Coordinates of the radial grid
!!  pawps
!!    %phi(mesh_size,basis_size)= PAW atomic wavefunctions
!!                                on the radial grid
!!  pshead
!!    %atomic_charge= Total atomic charge
!!    %bigmesh_size= Dimension of radial mesh for read coredens/valedens
!!    %core_charge= Core charge
!!    %lmn_size= Number of elements for the paw basis
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %rad_step= Step corresponding to radial mesh
!!
!! OUTPUT
!!  pawarray
!!    %vhnzc(bigmesh_size)= Hartree potential of the density
!!                          of the nucleus + core electrons
!!    %vhnzcij(lmn2_size)= (i,j) channel of the Hartree term inside
!!                         the spheres for the density nZc
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!      ctrap,poisson
!!
!! SOURCE

 subroutine calc_vhnzc(pawarray,pawdata,pawps,pshead)

  use defs_pawps
  use defs_basis

  implicit none

!Arguments ---------------------------------------------
!These types are defined in defs_pawps
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: ilm,ilmn,iln,ir,jlm,jlmn,jln,j0lmn,klmn
 real(dp) :: yp1,yp2,yp3
 real(dp), allocatable :: ff(:),vcore(:)

!--------------------------------------------------------

!Compute core potential VhnZc=Vh(Nc)*r
!----------------------------------------------------------
 allocate(vcore(pshead%bigmesh_size));vcore(1)=zero
 call poisson(pawarray%coreden4pr2(2:pshead%bigmesh_size),&
&             pshead%rad_step,pshead%bigmesh_size-1,pshead%core_charge,&
&             vcore(2:pshead%bigmesh_size))

!Divide VhnZc by r and add nuclear potential
!-------------------------------------------
 do ir=2,pshead%bigmesh_size
  pawarray%vhnzc(ir)=(vcore(ir)-pshead%atomic_charge)/pawdata%rad(ir)
 enddo
 deallocate(vcore)
!Deduce VhnZc at r=0
 yp2=(pawarray%vhnzc(3)-pawarray%vhnzc(2))/(pawdata%rad(3)-pawdata%rad(2))
 yp3=(pawarray%vhnzc(4)-pawarray%vhnzc(3))/(pawdata%rad(4)-pawdata%rad(3))
 yp1=yp2+(yp2-yp3)*(pawdata%rad(2)-pawdata%rad(1))/(pawdata%rad(3)-pawdata%rad(2))
 pawarray%vhnzc(1)=pawarray%vhnzc(2)-(yp1+yp2)*pawdata%rad(2)

!Compute the matrix element <phi_i|vh(nZc)|phi_j>
!------------------------------------------------
 allocate(ff(pshead%mesh_size))
 pawarray%vhnzcij=zero
 do jlmn=1,pshead%lmn_size
  j0lmn=jlmn*(jlmn-1)/2
  jlm=pawdata%indlmn(4,jlmn);jln=pawdata%indlmn(5,jlmn)
  do ilmn=1,jlmn
   klmn=j0lmn+ilmn
   ilm=pawdata%indlmn(4,ilmn);iln=pawdata%indlmn(5,ilmn)
   if (jlm==ilm) then
    do ir=1,pshead%mesh_size
     ff(ir)=pawps%phi(ir,iln)*pawarray%vhnzc(ir)*pawps%phi(ir,jln)
    enddo
    call ctrap(pshead%mesh_size,ff,pshead%rad_step,&
&              pawarray%vhnzcij(klmn))
   endif
  enddo
 enddo
 deallocate(ff)

 end subroutine calc_vhnzc

!!***
