!{\src2tex{textfont=tt}}
!!****f* ABINIT/initpawps2
!! NAME
!! initpawps2
!! 
!! FUNCTION
!! Initialize several quantities concerning the radial mesh and
!! pseudopotential type
!!
!! COPYRIGHT
!! Copyright (C) 1998-2004 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS 
!!  pshead
!!    %bigmesh_size= Dimension of radial mesh for read coredens/valedens
!!    %mesh_size= Dimension of radial mesh for phi, tphi ...
!!    %pspxc_atom= AtomPaw s code number for the exchange-correlation
!!    %rad_step= Step corresponding to radial mesh
!! 
!! OUTPUT
!!  pawdata
!!    %rad(bigmesh_size)= Coordinates of the radial grid
!!  pshead
!!    %creatorid= ID of psp generator (here pspfmt=1 !)
!!    %mesh_type=  Flag defining ther radial grid type
!!    %pspcod= Psp code number for Abinit (here PAW->pspcod=7 !)
!!    %pspxc_abinit= Abinit s code number for the exchange-correlation
!!    %rc_sph= Default PAW sphere radius
!!
!! PARENTS
!!      atompaw2abinit
!!
!! SOURCE

 subroutine initpawps2(pawdata,pshead)

 use defs_basis
 use defs_pawps

 implicit none
 
!Arguments ---------------------------------------------
!These types are defined in defs_pawps
 type(pawdata_type) :: pawdata
 type(pshead_type) :: pshead

!Local variables ---------------------------------------
 integer :: ir
 real(dp) :: rmax_vloc
!--------------------------------------------------------

!Format codes for Abinit pseudopotential
 pshead%creatorid=1
 pshead%pspcod=7

!Grid type (here, regular grid)
 pshead%mesh_type=1

!Mesh radii
 pshead%rc_sph=pshead%rad_step*dble(pshead%mesh_size-1)

!Size of mesh for Vloc:
!We decide to cut at r=10u.a because of numeric noise...
 rmax_vloc=10.d0
 pshead%vloc_meshsz=max(pshead%mesh_size,min(pshead%bigmesh_size,int(1.d0+rmax_vloc/pshead%rad_step)))

!Initialization of the radial mesh (rad)
 do ir=1,pshead%bigmesh_size
  pawdata%rad(ir)=(ir-1)*pshead%rad_step
 enddo

!Translation of the exchange-correlation type
!   --LDA calculation with the PW 92 functional
 if(pshead%pspxc_atom==14) then
  pshead%pspxc_abinit=7
!   --GGA calculation with the PBE functional
 elseif (pshead%pspxc_atom==16) then
  pshead%pspxc_abinit=11
 else
  write(6,*) 'Big Pb: exchange and correlation'
  write(6,*) '        fonctionnal does not exist !'
  stop
 endif

 end subroutine
!!***
